nplots: nplots: A convenient way of plotting various plot types based...

Description Note Author(s) See Also

Description

To avoid repetitive writing of code that generates plots, use this awesome package to call functions that plot various plots based off of ggplot2. Version 0.1.0 of this package provides the nplots_scatter() and nplots_violin() functions to generate scatter and violin plots from ggplot2 respectively.

Note

This is version 0.1.0 of nplots (November 2018). Future package development will provide an inclusion of other plot types (like box, line, bar, tile e.t.c) and more plot layers and objects to work with.

Author(s)

Rebecca Asiimwe

See Also

Useful links: http://ggplot2.tidyverse.org


STAT545-UBC-students/hw07-rasiimwe documentation built on May 5, 2019, 7:07 a.m.