Description Note Author(s) See Also
To avoid repetitive writing of code that generates plots, use this awesome package to call functions that plot various plots based off of ggplot2. Version 0.1.0 of this package provides the nplots_scatter() and nplots_violin() functions to generate scatter and violin plots from ggplot2 respectively.
This is version 0.1.0 of nplots (November 2018). Future package development will provide an inclusion of other plot types (like box, line, bar, tile e.t.c) and more plot layers and objects to work with.
Rebecca Asiimwe
Useful links: http://ggplot2.tidyverse.org
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.